@@ -341,8 +341,8 @@ UpdateWalk::UpdateDirectory(Directory &directory,
 
 	try {
 		Mutex mutex;
-		auto is = InputStream::OpenReady(PathTraitsUTF8::Build(storage.MapUTF8(directory.GetPath()).c_str(),
-								       ".mpdignore").c_str(),
+		auto is = InputStream::OpenReady(storage.MapUTF8(PathTraitsUTF8::Build(directory.GetPath(),
+										       ".mpdignore").c_str()).c_str(),
 						 mutex);
 		child_exclude_list.Load(std::move(is));
 	} catch (...) {
