@@ -90,6 +90,7 @@ DecoderControl::IsCurrentSong(const DetachedSong &_song) const noexcept
 void
 DecoderControl::Start(std::unique_ptr<DetachedSong> _song,
 		      SongTime _start_time, SongTime _end_time,
+		      bool _initial_seek_essential,
 		      MusicBuffer &_buffer,
 		      std::shared_ptr<MusicPipe> _pipe) noexcept
 {
@@ -99,6 +100,7 @@ DecoderControl::Start(std::unique_ptr<DetachedSong> _song,
 	song = std::move(_song);
 	start_time = _start_time;
 	end_time = _end_time;
+	initial_seek_essential = _initial_seek_essential;
 	buffer = &_buffer;
 	pipe = std::move(_pipe);
 
