@@ -414,7 +414,7 @@ faad_stream_decode(DecoderClient &client, InputStream &is)
 }
 
 static bool
-faad_scan_stream(InputStream &is, TagHandler &handler) noexcept
+faad_scan_stream(InputStream &is, TagHandler &handler)
 {
 	auto result = faad_get_file_time(is);
 	if (!result.first)
