@@ -275,7 +275,7 @@ mpcdec_get_file_duration(InputStream &is)
 }
 
 static bool
-mpcdec_scan_stream(InputStream &is, TagHandler &handler) noexcept
+mpcdec_scan_stream(InputStream &is, TagHandler &handler)
 {
 	const auto duration = mpcdec_get_file_duration(is);
 	if (duration.IsNegative())
