@@ -33,12 +33,14 @@ struct OpusHead {
 
 bool
 ScanOpusHeader(const void *data, size_t size, unsigned &channels_r,
-	       unsigned &pre_skip_r)
+	       signed &output_gain_r, unsigned &pre_skip_r)
 {
 	const OpusHead *h = (const OpusHead *)data;
 	if (size < 19 || (h->version & 0xf0) != 0)
 		return false;
 
+	output_gain_r = FromLE16S(h->output_gain);
+
 	channels_r = h->channels;
 	pre_skip_r = FromLE16(h->pre_skip);
 	return true;
