@@ -25,9 +25,16 @@
 #include "fs/AllocatedPath.hxx"
 #include "fs/FileSystem.hxx"
 #include "fs/Path.hxx"
+#include "fs/NarrowPath.hxx"
 #include "Log.hxx"
 #include "PluginUnavailable.hxx"
 
+#ifdef _WIN32
+/* assume WildMidi is built as static library on Windows; without
+   this, linking to the static library would fail */
+#define WILDMIDI_STATIC
+#endif
+
 extern "C" {
 #include <wildmidi_lib.h>
 }
@@ -53,7 +60,8 @@ wildmidi_init(const ConfigBlock &block)
 	AtScopeExit() { WildMidi_ClearError(); };
 #endif
 
-	if (WildMidi_Init(path.c_str(), wildmidi_audio_format.sample_rate,
+	if (WildMidi_Init(NarrowPath(path),
+			  wildmidi_audio_format.sample_rate,
 			  0) != 0) {
 #ifdef LIBWILDMIDI_VERSION
 		/* WildMidi_GetError() requires libwildmidi 0.4 */
@@ -96,7 +104,7 @@ wildmidi_file_decode(DecoderClient &client, Path path_fs)
 	midi *wm;
 	const struct _WM_Info *info;
 
-	wm = WildMidi_Open(path_fs.c_str());
+	wm = WildMidi_Open(NarrowPath(path_fs));
 	if (wm == nullptr)
 		return;
 
@@ -136,7 +144,7 @@ wildmidi_file_decode(DecoderClient &client, Path path_fs)
 static bool
 wildmidi_scan_file(Path path_fs, TagHandler &handler) noexcept
 {
-	midi *wm = WildMidi_Open(path_fs.c_str());
+	midi *wm = WildMidi_Open(NarrowPath(path_fs));
 	if (wm == nullptr)
 		return false;
 
