@@ -94,7 +94,7 @@ public:
 };
 
 PreparedFlacEncoder::PreparedFlacEncoder(const ConfigBlock &block)
-	:compression(block.GetBlockValue("compression", 5u))
+	:compression(block.GetBlockValue("compression", 5U))
 {
 }
 
