@@ -84,7 +84,7 @@ PreparedVorbisEncoder::PreparedVorbisEncoder(const ConfigBlock &block)
 		char *endptr;
 		quality = ParseDouble(value, &endptr);
 
-		if (*endptr != '\0' || quality < -1.0 || quality > 10.0)
+		if (*endptr != '\0' || quality < -1.0f || quality > 10.0f)
 			throw FormatRuntimeError("quality \"%s\" is not a number in the "
 						 "range -1 to 10",
 						 value);
@@ -122,13 +122,13 @@ VorbisEncoder::VorbisEncoder(float quality, int bitrate,
 	_audio_format.format = SampleFormat::FLOAT;
 	audio_format = _audio_format;
 
-	if (quality >= -1.0) {
+	if (quality >= -1.0f) {
 		/* a quality was configured (VBR) */
 
 		if (0 != vorbis_encode_init_vbr(&vi,
 						audio_format.channels,
 						audio_format.sample_rate,
-						quality * 0.1)) {
+						quality * 0.1f)) {
 			vorbis_info_clear(&vi);
 			throw std::runtime_error("error initializing vorbis vbr");
 		}
@@ -138,7 +138,7 @@ VorbisEncoder::VorbisEncoder(float quality, int bitrate,
 		if (0 != vorbis_encode_init(&vi,
 					    audio_format.channels,
 					    audio_format.sample_rate, -1.0,
-					    bitrate * 1000, -1.0)) {
+					    bitrate * 1000, -1.0f)) {
 			vorbis_info_clear(&vi);
 			throw std::runtime_error("error initializing vorbis encoder");
 		}
