@@ -26,6 +26,8 @@
 #include "system/FileDescriptor.hxx"
 #include "util/RuntimeError.hxx"
 
+#include <cinttypes> // for PRIu64 (PRIoffset)
+
 #include <sys/stat.h>
 #include <fcntl.h>
 
@@ -94,6 +96,11 @@ FileInputStream::Read(void *ptr, size_t read_size)
 		nbytes = reader.Read(ptr, read_size);
 	}
 
+	if (nbytes == 0 && !IsEOF())
+		throw FormatRuntimeError("Unexpected end of file %s"
+					 " at %" PRIoffset " of %" PRIoffset,
+					 GetURI(), GetOffset(), GetSize());
+
 	offset += nbytes;
 	return nbytes;
 }
