@@ -238,18 +238,18 @@ SetupHw(snd_pcm_t *pcm,
 	snd_pcm_hw_params_get_buffer_size_min(hwparams, &buffer_size_min);
 	snd_pcm_hw_params_get_buffer_size_max(hwparams, &buffer_size_max);
 	unsigned buffer_time_min, buffer_time_max;
-	snd_pcm_hw_params_get_buffer_time_min(hwparams, &buffer_time_min, 0);
-	snd_pcm_hw_params_get_buffer_time_max(hwparams, &buffer_time_max, 0);
+	snd_pcm_hw_params_get_buffer_time_min(hwparams, &buffer_time_min, nullptr);
+	snd_pcm_hw_params_get_buffer_time_max(hwparams, &buffer_time_max, nullptr);
 	FormatDebug(alsa_output_domain, "buffer: size=%u..%u time=%u..%u",
 		    (unsigned)buffer_size_min, (unsigned)buffer_size_max,
 		    buffer_time_min, buffer_time_max);
 
 	snd_pcm_uframes_t period_size_min, period_size_max;
-	snd_pcm_hw_params_get_period_size_min(hwparams, &period_size_min, 0);
-	snd_pcm_hw_params_get_period_size_max(hwparams, &period_size_max, 0);
+	snd_pcm_hw_params_get_period_size_min(hwparams, &period_size_min, nullptr);
+	snd_pcm_hw_params_get_period_size_max(hwparams, &period_size_max, nullptr);
 	unsigned period_time_min, period_time_max;
-	snd_pcm_hw_params_get_period_time_min(hwparams, &period_time_min, 0);
-	snd_pcm_hw_params_get_period_time_max(hwparams, &period_time_max, 0);
+	snd_pcm_hw_params_get_period_time_min(hwparams, &period_time_min, nullptr);
+	snd_pcm_hw_params_get_period_time_max(hwparams, &period_time_max, nullptr);
 	FormatDebug(alsa_output_domain, "period: size=%u..%u time=%u..%u",
 		    (unsigned)period_size_min, (unsigned)period_size_max,
 		    period_time_min, period_time_max);
