@@ -62,6 +62,6 @@ FfmpegLogCallback(gcc_unused void *ptr, int level, const char *fmt, va_list vl)
 					 ffmpeg_domain.GetName(),
 					 cls->item_name(ptr));
 		const Domain d(domain);
-		LogFormatV(d, FfmpegImportLogLevel(level), fmt, vl);
+		LogFormatV(FfmpegImportLogLevel(level), d, fmt, vl);
 	}
 }
