@@ -109,7 +109,7 @@ IcuCollate(const char *a, const char *b) noexcept
 	}
 
 	auto result = CompareStringEx(LOCALE_NAME_INVARIANT,
-				      LINGUISTIC_IGNORECASE,
+				      NORM_IGNORECASE,
 				      wa.c_str(), -1,
 				      wb.c_str(), -1,
 				      nullptr, nullptr, 0);
