@@ -191,7 +191,9 @@ static constexpr int
 events_to_libnfs(unsigned i) noexcept
 {
 	return ((i & SocketMonitor::READ) ? POLLIN : 0) |
-		((i & SocketMonitor::WRITE) ? POLLOUT : 0);
+		((i & SocketMonitor::WRITE) ? POLLOUT : 0) |
+		((i & SocketMonitor::HANGUP) ? POLLHUP : 0) |
+		((i & SocketMonitor::ERROR) ? POLLERR : 0);
 }
 
 NfsConnection::~NfsConnection() noexcept
@@ -450,8 +452,7 @@ NfsConnection::ScheduleSocket() noexcept
 		SocketMonitor::Open(_fd);
 	}
 
-	SocketMonitor::Schedule(libnfs_to_events(which_events)
-				| SocketMonitor::HANGUP);
+	SocketMonitor::Schedule(libnfs_to_events(which_events));
 }
 
 inline int
