@@ -70,7 +70,7 @@ audio_output_state_read(const char *line, MultipleOutputs &outputs)
 
 	name = endptr + 1;
 	auto *ao = outputs.FindByName(name);
-	if (ao == NULL) {
+	if (ao == nullptr) {
 		FormatDebug(output_domain,
 			    "Ignoring device state for '%s'", name);
 		return true;
