@@ -17,6 +17,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include "LocateUri.hxx"
 #include "PlaylistAny.hxx"
 #include "PlaylistStream.hxx"
 #include "PlaylistMapper.hxx"
@@ -25,17 +26,26 @@
 #include "config.h"
 
 std::unique_ptr<SongEnumerator>
-playlist_open_any(const char *uri,
+playlist_open_any(const LocatedUri &located_uri,
 #ifdef ENABLE_DATABASE
 		  const Storage *storage,
 #endif
 		  Mutex &mutex)
 {
-	return uri_has_scheme(uri)
-		? playlist_open_remote(uri, mutex)
-		: playlist_mapper_open(uri,
+	switch (located_uri.type) {
+	case LocatedUri::Type::ABSOLUTE:
+		return playlist_open_remote(located_uri.canonical_uri, mutex);
+
+	case LocatedUri::Type::PATH:
+		return playlist_open_path(located_uri.path, mutex);
+
+	case LocatedUri::Type::RELATIVE:
+		return playlist_mapper_open(located_uri.canonical_uri,
 #ifdef ENABLE_DATABASE
 				       storage,
 #endif
 				       mutex);
+	}
+
+	gcc_unreachable();
 }
